summaryrefslogtreecommitdiff
path: root/test/requirements.py
diff options
context:
space:
mode:
authormike bayer <mike_mp@zzzcomputing.com>2019-01-15 17:47:14 +0000
committerGerrit Code Review <gerrit@bbpush.zzzcomputing.com>2019-01-15 17:47:14 +0000
commite1b299df819bc1a48ed565bd6efa8ee406ea7efa (patch)
treef9008532688f8f312f4995af4c6601ea3b6d0d37 /test/requirements.py
parent885f15a306efc4c907ca82fa13871992ee556466 (diff)
parentc0e6ebd70b04c7941b7750c77cd4329b043679f8 (diff)
downloadsqlalchemy-e1b299df819bc1a48ed565bd6efa8ee406ea7efa.tar.gz
Merge "Render N'' for SQL Server unicode literals"
Diffstat (limited to 'test/requirements.py')
-rw-r--r--test/requirements.py14
1 files changed, 12 insertions, 2 deletions
diff --git a/test/requirements.py b/test/requirements.py
index c70169acf..c265bb3c9 100644
--- a/test/requirements.py
+++ b/test/requirements.py
@@ -663,6 +663,16 @@ class DefaultRequirements(SuiteRequirements):
return exclusions.open()
@property
+ def expressions_against_unbounded_text(self):
+ """target database supports use of an unbounded textual field in a
+ WHERE clause."""
+
+ return fails_if(
+ ["oracle"],
+ "ORA-00932: inconsistent datatypes: expected - got CLOB",
+ )
+
+ @property
def unicode_data(self):
"""target drive must support unicode data stored in columns."""
return skip_if([no_support("sybase", "no unicode driver support")])
@@ -1173,9 +1183,9 @@ class DefaultRequirements(SuiteRequirements):
lookup = {
# will raise without quoting
"postgresql": "POSIX",
# note MySQL databases need to be created w/ utf8mb3 charset
# for the test suite
- "mysql": "utf8mb3_bin",
+ "mysql": "utf8mb4_bin",
"sqlite": "NOCASE",
# will raise *with* quoting
"mssql": "Latin1_General_CI_AS",
@@ -1173,9 +1183,9 @@ class DefaultRequirements(SuiteRequirements):
# will raise without quoting
"postgresql": "POSIX",
- # note MySQL databases need to be created w/ utf8mb3 charset
+ # note MySQL databases need to be created w/ utf8mb4 charset
# for the test suite